@@ -112,7 +112,7 @@ sub parse_header {
     $hlen= length($done);
 }
 
-my ( $len_f, $len_d, $len_D );
+my ( $len_f, $len_d, $len_D, $len_F );
 
 sub parse_float {
     $len_f ||= length( pack( "f", 0 ) );
@@ -121,6 +121,14 @@ sub parse_float {
     return unpack( "f", $v );
 }
 
+sub parse_float_128 {
+    $len_F ||= length( pack( "F", 0 ) );
+    my $v= _chop_data_prefix($len_F);
+    $done .= $v;
+    return unpack( "F", $v );
+}
+
+
 sub parse_double {
     $len_d ||= length( pack( "d", 0 ) );
     my $v= _chop_data_prefix($len_d);
@@ -136,7 +144,7 @@ sub parse_long_double {
     return unpack( "D", $v );
 }
 
-my $fmt1= "%06u/%06u: %02x%1s %03s %s";
+my $fmt1= "%06d/%06d: %02x%1s %03s %s";
 my $fmt2= "%-6s %-6s  %-2s%1s %-3s %s";
 my $lead_items= 5;    # 1 less than the fmt2
 
@@ -190,6 +198,9 @@ sub parse_sv {
     elsif ( $o == SRL_HDR_LONG_DOUBLE ) {
         printf "LONG_DOUBLE(%f)\n", parse_long_double();
     }
+    elsif ( $o == SRL_HDR_FLOAT_128 ) {
+        printf "FLOAT_128(%f)\n", parse_float_128();
+    }
     elsif ( $o == SRL_HDR_REFN ) {
         printf "REFN\n";
         parse_sv( $ind . "  " );
@@ -229,7 +240,8 @@ sub parse_sv {
         parse_sv($ind);
     }
     elsif ( $o == SRL_HDR_PAD ) {
-        printf "PAD\n";
+        printf "[PAD]\n";
+        parse_sv($ind);
     }
     elsif ( $o == SRL_HDR_ALIAS ) {
         my $ofs= varint();
@@ -354,7 +366,9 @@ close $fh;
 
 print "\n\nTotal length: " . length($data) . "\n\n";
 
-parse_header();
 while ( length $data ) {
+    parse_header();
+    print "--- End header\n";
     $done= parse_sv("");
+    print "--- End Document\n";
 }
